========
Scrapple
========

.. image:: https://travis-ci.org/scrappleapp/scrapple.svg
    :target: https://travis-ci.org/scrappleapp/scrapple
    :alt: Travis-CI Build Status

.. image:: https://pypip.in/download/scrapple/badge.svg
    :target: https://pypi.python.org/pypi//scrapple
    :alt: Downloads

.. image:: https://pypip.in/version/scrapple/badge.svg?text=version
    :target: https://pypi.python.org/pypi/scrapple
    :alt: Latest Version


`Scrapple`_ is a framework for creating web scrapers and web crawlers according to a key-value based configuration file. It provides a command line interface to run the script on a given JSON-based configuration input, as well as a web interface to provide the necessary input.

You can install Scrapple by using

::

	$ sudo apt-get install libxml2-dev libxslt-dev python-dev lib32z1-dev
	$ pip install scrapple


You can read the `complete documentation`_.

.. _Scrapple: http://scrappleapp.github.io/scrapple
.. _complete documentation: http://scrapple.rtfd.org
